==> actions-recorder-1.1.0.tgz: package/lib/devtools.js <==
var Immutable, React, Viewer, classnames, diff, div, keycode, locale, pre, recorder, ref, tabs;

diff = require('immutablediff');

React = require('react/addons');

keycode = require('keycode');

Immutable = require('immutable');

classnames = require('classnames');

recorder = require('./recorder');

locale = require('./app/locale');

Viewer = React.createFactory(require('./app/viewer'));

ref = React.DOM, div = ref.div, pre = ref.pre;

tabs = ['action', 'store', 'diff'];

module.exports = React.createClass({
  displayName: "actions-recorder-devtools",
  mixins: [React.addons.PureRenderMixin],
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.Collection).isRequired,
    records: React.PropTypes.instanceOf(Immutable.List).isRequired,
    initial: React.PropTypes.instanceOf(Immutable.Collection).isRequired,
    updater: React.PropTypes.func.isRequired,
    pointer: React.PropTypes.number.isRequired,
    isTravelling: React.PropTypes.bool.isRequired,
    language: React.PropTypes.string,
    width: React.PropTypes.number.isRequired,
    height: React.PropTypes.number.isRequired
  },
  getDefaultProps: function() {
    return {
      language: 'en'
    };
  },
  getInitialState: function() {
    return {
      tab: 'action'
    };
  },
  getStoreAtPointer: function(pointer) {
    var result, updater;
    if (pointer < 1) {
      return result = this.props.initial;
    } else {
      updater = (function(_this) {
        return function(acc, record) {
          return _this.props.updater(acc, record.get(0), record.get(1));
        };
      })(this);
      return result = this.props.records.slice(0, pointer).reduce(updater, this.props.initial);
    }
  },
  onTabSelect: function(name) {
    return this.setState({
      tab: name
    });
  },
  onCommit: function() {
    return recorder.dispatch("actions-recorder/commit");
  },
  onReset: function() {
    return recorder.dispatch("actions-recorder/reset");
  },
  onPeek: function(position) {
    return recorder.dispatch("actions-recorder/peek", position);
  },
  onRun: function() {
    return recorder.dispatch("actions-recorder/run");
  },
  onMergeBefore: function() {
    if (this.props.pointer > 0) {
      return recorder.dispatch("actions-recorder/merge-before");
    }
  },
  onClearAfter: function() {
    return recorder.dispatch("actions-recorder/clear-after");
  },
  onStep: function(event) {
    return recorder.dispatch('actions-recorder/step', event.shiftKey);
  },
  onInitialClick: function() {
    return recorder.dispatch('actions-recorder/peek', 0);
  },
  renderItem: function(record, originalIndex) {
    var index, isSelected, onClick;
    index = originalIndex + 1;
    onClick = (function(_this) {
      return function() {
        return _this.onPeek(index);
      };
    })(this);
    isSelected = this.props.pointer === index && this.props.isTravelling;
    return div({
      key: index,
      style: this.styleItem(isSelected),
      onClick: onClick
    }, record.get(0));
  },
  renderAction: function() {
    var actionData, record;
    if (this.props.pointer > 0) {
      record = this.props.records.get(this.props.pointer - 1);
      actionData = record.get(1);
    } else {
      actionData = null;
    }
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: actionData
    });
  },
  renderStore: function() {
    var result;
    result = this.getStoreAtPointer(this.props.pointer);
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: result
    });
  },
  renderDiff: function() {
    var changes, error, prevResult, result;
    result = this.getStoreAtPointer(this.props.pointer);
    prevResult = this.getStoreAtPointer(this.props.pointer - 1);
    try {
      changes = diff(prevResult, result);
    } catch (_error) {
      error = _error;
      changes = error;
    }
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: changes
    });
  },
  renderCurrent: function() {
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: this.props.store
    });
  },
  renderDetails: function() {
    return div({
      style: this.styleDetails()
    }, div({
      style: this.styleMode()
    }, tabs.map((function(_this) {
      return function(name) {
        var onClick;
        onClick = function() {
          return _this.onTabSelect(name);
        };
        return div({
          style: _this.styleEntry(name === _this.state.tab),
          onClick: onClick,
          key: name
        }, name);
      };
    })(this))), (function() {
      switch (this.state.tab) {
        case 'action':
          return this.renderAction();
        case 'store':
          return this.renderStore();
        case 'diff':
          return this.renderDiff();
      }
    }).call(this));
  },
  render: function() {
    var hint, isInitialSelected, showClearAfter, showCommit, showMergeBefore, showReset, showRun, showStep;
    hint = (function(_this) {
      return function(text) {
        return locale.get(text, _this.props.language);
      };
    })(this);
    isInitialSelected = this.props.pointer === 0 && this.props.isTravelling;
    showMergeBefore = this.props.pointer > 0 && this.props.isTravelling;
    showClearAfter = this.props.pointer < this.props.records.size && this.props.isTravelling;
    showReset = this.props.records.size > 0;
    showCommit = this.props.records.size > 0;
    showRun = this.props.isTravelling;
    showStep = this.props.isTravelling && this.props.records.size > 0;
    return div({
      style: this.styleRoot()
    }, div({
      style: this.styleHeader()
    }, div({
      style: this.styleButton(showMergeBefore),
      onClick: this.onMergeBefore
    }, hint('mergeBefore')), div({
      style: this.styleButton(showClearAfter),
      onClick: this.onClearAfter
    }, hint('clearAfter')), div({
      style: this.styleButton(showReset),
      onClick: this.onReset
    }, hint('reset')), div({
      style: this.styleButton(showCommit),
      onClick: this.onCommit
    }, hint('commit')), div({
      style: this.styleButton(showRun),
      onClick: this.onRun
    }, hint('run')), div({
      style: this.styleButton(showStep),
      onClick: this.onStep
    }, hint('step')), div({
      style: this.styleTip()
    }, "(" + this.props.pointer + "/" + this.props.records.size + ")")), div({
      style: this.styleViewer()
    }, div({
      style: this.styleMonitor()
    }, div({
      style: this.styleItem(isInitialSelected),
      onClick: this.onInitialClick
    }, '__initial__'), this.props.records.map(this.renderItem)), this.props.isTravelling && (this.props.records.get(this.props.pointer - 1) != null) ? this.renderDetails() : this.renderCurrent()));
  },
  styleRoot: function() {
    return {
      background: 'hsla(200,60%,40%,0.7)',
      color: 'white',
      fontFamily: 'Menlo, Consolas, monospace',
      lineHeight: '1.8em',
      display: 'flex',
      height: '100%',
      flexDirection: 'column',
      transitionProperty: 'left, top',
      transitionDuration: '300ms',
      zIndex: 9999,
      flex: 1
    };
  },
  styleButton: function(isAvailable) {
    return {
      display: 'inline-block',
      backgroundColor: isAvailable ? 'hsla(0,100%,100%,0.2)' : 'hsla(0,100%,80%,0.2)',
      color: isAvailable ? 'white' : 'hsla(0,100%,100%,0.4)',
      marginRight: '10px',
      padding: '0 10px',
      fontSize: '14px',
      fontFamily: 'Verdana, Helvetica, sans-serif',
      lineHeight: '30px',
      cursor: 'pointer'
    };
  },
  styleEntry: function(isSelected) {
    return {
      display: 'inline-block',
      backgroundColor: isSelected ? 'hsla(0,100%,100%,0.5)' : 'hsla(0,100%,100%,0.2)',
      marginRight: '10px',
      padding: '0 10px',
      fontSize: '14px',
      fontFamily: 'Verdana, Helvetica, sans-serif',
      lineHeight: '30px',
      cursor: 'pointer'
    };
  },
  styleHeader: function() {
    return {
      WebkitUserSelect: 'none',
      marginBottom: '10px'
    };
  },
  styleViewer: function() {
    return {
      flex: 1,
      display: 'flex',
      flexDirection: 'row',
      height: this.props.height - 40,
      position: 'relative'
    };
  },
  styleMonitor: function() {
    return {
      width: '250px',
      marginRight: '10px',
      overflowX: 'hidden',
      paddingBottom: '40px',
      height: this.props.height - 40
    };
  },
  styleItem: function(isPointer) {
    return {
      cursor: 'pointer',
      lineHeight: '30px',
      fontSize: '13px',
      padding: '0 10px',
      backgroundColor: isPointer ? 'hsla(0,100%,100%,0.2)' : 'transparent'
    };
  },
  styleDetails: function() {
    return {
      flex: 1,
      overflow: 'auto',
      display: 'flex',
      flexDirection: 'column'
    };
  },
  styleMode: function() {
    return {
      height: '30px',
      flexDirection: 'row'
    };
  },
  styleTip: function() {
    return {
      fontSize: '12px',
      display: 'inline-block'
    };
  }
});

==> actions-recorder-1.1.2.tgz: package/lib/devtools.js <==
var Immutable, React, Viewer, classnames, diff, div, keycode, locale, pre, recorder, ref, tabs;

diff = require('immutablediff');

React = require('react/addons');

keycode = require('keycode');

Immutable = require('immutable');

classnames = require('classnames');

recorder = require('./recorder');

locale = require('./app/locale');

Viewer = React.createFactory(require('./app/viewer'));

ref = React.DOM, div = ref.div, pre = ref.pre;

tabs = ['action', 'store', 'diff'];

module.exports = React.createClass({
  displayName: "actions-recorder-devtools",
  mixins: [React.addons.PureRenderMixin],
  propTypes: {
    store: React.PropTypes.instanceOf(Immutable.Collection).isRequired,
    records: React.PropTypes.instanceOf(Immutable.List).isRequired,
    initial: React.PropTypes.instanceOf(Immutable.Collection).isRequired,
    updater: React.PropTypes.func.isRequired,
    pointer: React.PropTypes.number.isRequired,
    isTravelling: React.PropTypes.bool.isRequired,
    language: React.PropTypes.string,
    width: React.PropTypes.number.isRequired,
    height: React.PropTypes.number.isRequired
  },
  getDefaultProps: function() {
    return {
      language: 'en'
    };
  },
  getInitialState: function() {
    return {
      tab: 'action'
    };
  },
  getStoreAtPointer: function(pointer) {
    var result, updater;
    if (pointer < 1) {
      return result = this.props.initial;
    } else {
      updater = (function(_this) {
        return function(acc, record) {
          return _this.props.updater(acc, record.get(0), record.get(1));
        };
      })(this);
      return result = this.props.records.slice(0, pointer).reduce(updater, this.props.initial);
    }
  },
  onTabSelect: function(name) {
    return this.setState({
      tab: name
    });
  },
  onCommit: function() {
    return recorder.dispatch("actions-recorder/commit");
  },
  onReset: function() {
    return recorder.dispatch("actions-recorder/reset");
  },
  onPeek: function(position) {
    return recorder.dispatch("actions-recorder/peek", position);
  },
  onRun: function() {
    return recorder.dispatch("actions-recorder/run");
  },
  onMergeBefore: function() {
    if (this.props.pointer > 0) {
      return recorder.dispatch("actions-recorder/merge-before");
    }
  },
  onClearAfter: function() {
    return recorder.dispatch("actions-recorder/clear-after");
  },
  onStep: function(event) {
    return recorder.dispatch('actions-recorder/step', event.shiftKey);
  },
  onInitialClick: function() {
    return recorder.dispatch('actions-recorder/peek', 0);
  },
  renderItem: function(record, originalIndex) {
    var index, isSelected, onClick;
    index = originalIndex + 1;
    onClick = (function(_this) {
      return function() {
        return _this.onPeek(index);
      };
    })(this);
    isSelected = this.props.pointer === index && this.props.isTravelling;
    return div({
      key: index,
      style: this.styleItem(isSelected),
      onClick: onClick
    }, record.get(0));
  },
  renderAction: function() {
    var actionData, record;
    if (this.props.pointer > 0) {
      record = this.props.records.get(this.props.pointer - 1);
      actionData = record.get(1);
    } else {
      actionData = null;
    }
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: actionData
    });
  },
  renderStore: function() {
    var result;
    result = this.getStoreAtPointer(this.props.pointer);
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: result
    });
  },
  renderDiff: function() {
    var changes, error, prevResult, result;
    result = this.getStoreAtPointer(this.props.pointer);
    prevResult = this.getStoreAtPointer(this.props.pointer - 1);
    try {
      changes = diff(prevResult, result);
    } catch (_error) {
      error = _error;
      changes = error;
    }
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: changes
    });
  },
  renderCurrent: function() {
    return Viewer({
      key: this.state.tab,
      height: this.props.height - 70,
      data: this.props.store
    });
  },
  renderDetails: function() {
    return div({
      style: this.styleDetails()
    }, div({
      style: this.styleMode()
    }, tabs.map((function(_this) {
      return function(name) {
        var onClick;
        onClick = function() {
          return _this.onTabSelect(name);
        };
        return div({
          style: _this.styleEntry(name === _this.state.tab),
          onClick: onClick,
          key: name
        }, name);
      };
    })(this))), (function() {
      switch (this.state.tab) {
        case 'action':
          return this.renderAction();
        case 'store':
          return this.renderStore();
        case 'diff':
          return this.renderDiff();
      }
    }).call(this));
  },
  render: function() {
    var hint, isInitialSelected, showClearAfter, showCommit, showMergeBefore, showReset, showRun, showStep;
    hint = (function(_this) {
      return function(text) {
        return locale.get(text, _this.props.language);
      };
    })(this);
    isInitialSelected = this.props.pointer === 0 && this.props.isTravelling;
    showMergeBefore = this.props.pointer > 0 && this.props.isTravelling;
    showClearAfter = this.props.pointer < this.props.records.size && this.props.isTravelling;
    showReset = this.props.records.size > 0;
    showCommit = this.props.records.size > 0;
    showRun = this.props.isTravelling;
    showStep = this.props.isTravelling && this.props.records.size > 0;
    return div({
      style: this.styleRoot()
    }, div({
      style: this.styleHeader()
    }, div({
      style: this.styleButton(showMergeBefore),
      onClick: this.onMergeBefore
    }, hint('mergeBefore')), div({
      style: this.styleButton(showClearAfter),
      onClick: this.onClearAfter
    }, hint('clearAfter')), div({
      style: this.styleButton(showReset),
      onClick: this.onReset
    }, hint('reset')), div({
      style: this.styleButton(showCommit),
      onClick: this.onCommit
    }, hint('commit')), div({
      style: this.styleButton(showRun),
      onClick: this.onRun
    }, hint('run')), div({
      style: this.styleButton(showStep),
      onClick: this.onStep
    }, hint('step')), div({
      style: this.styleTip()
    }, "(" + this.props.pointer + "/" + this.props.records.size + ")")), div({
      style: this.styleViewer()
    }, div({
      style: this.styleMonitor()
    }, div({
      style: this.styleItem(isInitialSelected),
      onClick: this.onInitialClick
    }, '__initial__'), this.props.records.map(this.renderItem)), this.props.isTravelling && (this.props.records.get(this.props.pointer - 1) != null) ? this.renderDetails() : this.renderCurrent()));
  },
  styleRoot: function() {
    return {
      background: 'hsla(0, 0%, 0%, 0.56)',
      color: 'white',
      fontFamily: 'Menlo, Consolas, Ubuntu Mono, monospace',
      lineHeight: '1.8em',
      display: 'flex',
      height: '100%',
      flexDirection: 'column',
      transitionProperty: 'left, top',
      transitionDuration: '300ms',
      zIndex: 9999,
      flex: 1
    };
  },
  styleButton: function(isAvailable) {
    return {
      display: 'inline-block',
      backgroundColor: isAvailable ? 'hsla(0,100%,100%,0.2)' : 'hsla(0,100%,80%,0.2)',
      color: isAvailable ? 'white' : 'hsla(0,100%,100%,0.4)',
      marginRight: '10px',
      padding: '0 10px',
      fontSize: '12px',
      fontFamily: 'Verdana, Helvetica, sans-serif',
      lineHeight: '30px',
      cursor: 'pointer'
    };
  },
  styleEntry: function(isSelected) {
    return {
      display: 'inline-block',
      backgroundColor: isSelected ? 'hsla(0,100%,100%,0.5)' : 'hsla(0,100%,100%,0.2)',
      marginRight: '10px',
      padding: '0 10px',
      fontSize: '12px',
      fontFamily: 'Verdana, Helvetica, sans-serif',
      lineHeight: '30px',
      cursor: 'pointer'
    };
  },
  styleHeader: function() {
    return {
      WebkitUserSelect: 'none',
      marginBottom: '10px'
    };
  },
  styleViewer: function() {
    return {
      flex: 1,
      display: 'flex',
      flexDirection: 'row',
      height: this.props.height - 40,
      position: 'relative'
    };
  },
  styleMonitor: function() {
    return {
      width: 'auto',
      paddingRight: '40px',
      marginRight: '10px',
      overflowX: 'hidden',
      paddingTop: '100px',
      paddingBottom: '100px',
      height: this.props.height - 40
    };
  },
  styleItem: function(isPointer) {
    return {
      cursor: 'pointer',
      lineHeight: '30px',
      fontSize: '12px',
      padding: '0 10px',
      backgroundColor: isPointer ? 'hsla(0,100%,100%,0.2)' : 'transparent'
    };
  },
  styleDetails: function() {
    return {
      flex: 1,
      overflow: 'auto',
      display: 'flex',
      flexDirection: 'column'
    };
  },
  styleMode: function() {
    return {
      height: '30px',
      flexDirection: 'row'
    };
  },
  styleTip: function() {
    return {
      fontSize: '12px',
      display: 'inline-block'
    };
  }
});
